:mod:`Affichage` --- Fonctions d'affichage
==========================================
Le module :mod:`Affichage`


.. automodule:: pyromaths.outils.Affichage
    :members:
    :special-members:
..    :private-members:
      :undoc-members:
      :show-inheritance:
